@@ -6,9 +6,10 @@ import os
 from sys import byteorder
 
 
-class SegFileWriter:
-    """Implementation segment write file"""
+class SegFile:
+    """Implementation segment file"""
     file: str
+    stat_file: str
     parts: int
     id: int
 
@@ -20,8 +21,9 @@ class SegFileWriter:
     sfp: FileIO
     sbs: int
 
-    def __init__(self, file: str, parts: int, seg_idx: int):
+    def __init__(self, file: str, stat_file: str, parts: int, seg_idx: int):
         self.file = file
+        self.stat_file = stat_file
         self.parts = parts
         self.id = seg_idx
         self.open()
@@ -32,7 +34,7 @@ class SegFileWriter:
 
     def _load_stat(self):
         # open stat file - must exists - buffering 0 - no need flush()
-        self.sfp = open(self.file + const.DOWNPOSTFIX, 'rb+', 0)
+        self.sfp = open(self.stat_file, 'rb+', 0)
         # byte size of stat segment
         self.sbs = int.from_bytes(self.sfp.read(1), byteorder)
         # total_size
@@ -48,24 +50,16 @@ class SegFileWriter:
             self.size = total_size - self.pfrom
 
         # get written
-        self.stat_pos = 1 + self.sbs + (self.id * self.sbs)
-        self.sfp.seek(self.stat_pos, os.SEEK_SET)
-        self.cur_pos = int.from_bytes(self.sfp.read(self.sbs), byteorder)
-        self.written = self.cur_pos - self.pfrom
+        self._read_stat()
 
         # seek file position
         self.fp.seek(self.cur_pos, os.SEEK_SET)
 
-    def _write_stat(self, newpos):
+    def _read_stat(self):
+        self.stat_pos = 1 + self.sbs + (self.id * self.sbs)
         self.sfp.seek(self.stat_pos, os.SEEK_SET)
-        self.sfp.write(newpos.to_bytes(self.sbs, byteorder))
-
-    def write(self, chunk):
-        self.fp.seek(self.cur_pos, os.SEEK_SET)
-        wrt = self.fp.write(chunk)
-        self.written += wrt
-        self.cur_pos += wrt
-        self._write_stat(self.cur_pos)
+        self.cur_pos = int.from_bytes(self.sfp.read(self.sbs), byteorder)
+        self.written = self.cur_pos - self.pfrom
 
     def close(self):
         if not self.sfp.closed:
@@ -74,9 +68,26 @@ class SegFileWriter:
             self.fp.close()
 
 
+class SegFileWriter(SegFile):
+    """Implementation segment write file"""
+
+    def _write_stat(self, newpos):
+        self.sfp.seek(self.stat_pos, os.SEEK_SET)
+        self.sfp.write(newpos.to_bytes(self.sbs, byteorder))
+
+    def write(self, chunk):
+        self.fp.seek(self.cur_pos, os.SEEK_SET)
+        wrt = self.fp.write(chunk)
+        self.fp.flush()
+        self.written += wrt
+        self.cur_pos += wrt
+        self._write_stat(self.cur_pos)
+
+
 class SegFileLoader:
-    def __init__(self, filename: str, size: int, parts: int):
-        self.filename = filename
+    def __init__(self, file: str, stat_file: str, size: int, parts: int):
+        self.file = file
+        self.stat_file = stat_file
         self.size = size
         self.parts = parts
         self._first_created = False
@@ -92,10 +103,10 @@ class SegFileLoader:
             parts = self._get_parts_from_existing()
             self.parts = parts
 
-        return [SegFileWriter(self.filename, parts, i) for i in range(parts)]
+        return [SegFileWriter(self.file, self.stat_file, parts, i) for i in range(parts)]
 
     def _get_parts_from_existing(self):
-        self.sfp = open(self.filename + const.DOWNPOSTFIX, 'rb')
+        self.sfp = open(self.stat_file, 'rb')
         sbs = int.from_bytes(self.sfp.read(1), byteorder)
         size = int.from_bytes(self.sfp.read(sbs), byteorder)
 
@@ -112,10 +123,10 @@ class SegFileLoader:
             return parts
 
     def _create_files_if_not_ex(self):
-        if not os.path.isfile(self.filename + const.DOWNPOSTFIX):
-            self.fp = open(self.filename, 'wb+')
+        if not os.path.isfile(self.stat_file):
+            self.fp = open(self.file, 'wb+')
             self.fp.truncate(self.size)
-            self.sfp = open(self.filename + const.DOWNPOSTFIX, 'wb+')
+            self.sfp = open(self.stat_file, 'wb+')
 
             self._make_stat_file_data(self.size, self.parts)
             self._first_created = True
@@ -132,51 +143,3 @@ class SegFileLoader:
             self.sfp.seek(stat_pos, os.SEEK_SET)
             seg = (i * self.part_size).to_bytes(sb_size, byteorder)
             self.sfp.write(seg)
-
-
-class SegFileMonitor:
-    """Monitor data in download status file (.udown)"""
-    progfile: str
-    sfp: FileIO = None
-    done: bool = False
-
-    def __init__(self, filename: str):
-        self.progfile = filename + const.DOWNPOSTFIX
-
-    def size(self):
-        if os.path.exists(self.progfile):
-            if self.sfp is None:
-                self.sfp = open(self.progfile, 'rb', 0)
-
-            self.sfp.seek(0)
-            self.sbs = int.from_bytes(self.sfp.read(1), byteorder)
-            self.file_size = int.from_bytes(self.sfp.read(self.sbs), byteorder)
-            start_segs_pos = self.sfp.tell()
-            self.sfp.seek(0, os.SEEK_END)
-            end_segs_pos = self.sfp.tell()
-            self.parts = (end_segs_pos - start_segs_pos) / self.sbs
-            self.seg_size = ceil(self.file_size / self.parts)
-
-            sizenow = 0
-            segidx = 0
-            self.sfp.seek(1 + self.sbs)
-            while segidx < self.parts:
-                sbytes = self.sfp.read(self.sbs)
-                if not sbytes:
-                    break
-
-                seg_from = segidx * self.seg_size
-                count_seg = int.from_bytes(sbytes, byteorder)
-
-                sizenow += count_seg - seg_from
-                segidx += 1
-            return sizenow
-        else:
-            return 0
-
-    def clean(self):
-        if self.file_size is not None:
-            if not self.sfp.closed:
-                self.sfp.close()
-            if os.path.exists(self.progfile):
-                os.remove(self.progfile)
